%global debug_package %{nil}

Summary:        Apple IIgs Emulator
Name:           kegs
Version:        1.16
Release:        1%{?dist}
License:        GPLv2
Group:          Applications/Emulators
URL:            https://sourceforge.net/p/kegs
Source0:        %{name}.%{version}.tar.gz
Source1:        %{name}-getroms.sh
Source4:        %{name}.png
Source5:        %{name}.desktop
Source6:        %{name}.appdata.xml

Requires:       xorg-x11-fonts-misc
Requires:       pulseaudio-utils
Requires:       pulseaudio-libs

BuildRequires:  desktop-file-utils
BuildRequires:  pulseaudio-libs-devel
BuildRequires:  libappstream-glib
BuildRequires:  libX11-devel
BuildRequires:  libXext-devel
BuildRequires:  libpcap-devel
BuildRequires:  gcc-c++


%description
GSport is a portable (in the programming sense) Apple IIgs emulator, based on
the KEGS cross-platform IIgs emulator by Kent Dickey. The base emulator builds
and runs on all of the same platforms that KEGS did, and the new capabilities
are being integrated as contributors have time and interest.

%prep
%autosetup -n %{name}.%{version}

%build
# Setup linux vars
pushd src
cat >vars <<'EOF'
TARGET = xkegs
OBJECTS1 = pulseaudio_driver.o xdriver.o
CC = gcc
CCOPTS = -O2 -Wall -fomit-frame-pointer -std=gnu99 -DPULSE_AUDIO
NAME = xkegs
LD = g++
EXTRA_LIBS = -lXext -lpulse
EXTRA_SPECIALS =
XOPTS = -I/usr/X11R6/include
EOF

%make_build

%clean
rm -rf $RPM_BUILD_ROOT

%install
install -d $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}
install -D -m 0755 xkegs            $RPM_BUILD_ROOT/%{_bindir}/xkegs.bin
install -D -m 0755 %{SOURCE1}       $RPM_BUILD_ROOT/%{_bindir}/%{name}-getroms.sh
install -D -m 0644 %{SOURCE4}       $RPM_BUILD_ROOT/%{_datadir}/pixmaps/%{name}.png
install -D -m 0644 %{SOURCE6}       $RPM_BUILD_ROOT/%{_datadir}/appdata/%{name}.appdata.xml

# Initial config for clean boot.
install -d $RPM_BUILD_ROOT/%{_datadir}/%{name}
cat >$RPM_BUILD_ROOT/%{_datadir}/%{name}/config.txt.dist <<EOF
# XKegs configuration file version 0.31

s5d1 =
s5d2 =

s6d1 =
s6d2 =

s7d1 = %{_datadir}/%{name}/NoBoot.po

g_joystick_type = 0
g_cfg_rom_path = ROM.03

EOF

# Startup wrapper
cat >$RPM_BUILD_ROOT/%{_bindir}/%{name} <<'EOF'
#!/usr/bin/env bash
# Simple wrapper to start GSportX via PulseAudio OSS Wrapper to enable
# sound via the older /dev/dsp interface.

# First run, get roms if needed and setup config file.
if [[ ! -f ${HOME}/.config/%{name}/config.txt && -n ${HOME} ]]; then
    /usr/bin/%{name}-getroms.sh
fi

cd %{_datadir}/%{name}
exec %{_bindir}/x%{name}.bin -audio 1
EOF

desktop-file-install --dir=$RPM_BUILD_ROOT%{_datadir}/applications %{SOURCE5}
appstream-util validate-relax --nonet $RPM_BUILD_ROOT/%{_datadir}/appdata/*.appdata.xml

%files
%defattr(-,root,root)
%doc COPYING.txt
%attr(755,root,root) %{_bindir}/*
%{_datadir}/%{name}/*
%{_datadir}/appdata/*
%{_datadir}/applications/*
%{_datadir}/pixmaps/*

%changelog
* Mon Jan 31 2022 Greg Wildman <greg@techno.co.za> - 1.16-1
- Updated to new version.

* Wed Jun 30 2021 Greg Wildman <greg@techno.co.za> - 1.08-1
- Updated to new version.

* Sun Jun 27 2021 Greg Wildman <greg@techno.co.za> - 1.07-1
- Updated to new version.

* Sat Aug 25 2018 Greg Wildman <greg@techno.co.za> - 0.31-15
- Add auto download of GS rom files.
- Patch to get closer to XDG spec.
- Change binary to "gsport"

* Thu May 24 2018 Greg Wildman <greg@techno.co.za> - 0.31-11
- Fix build dependencies.

* Sun Sep 25 2016 Greg Wildman <greg@techno.co.za> - 0.31-7
- Include GUI .desktop file and appdata xml.

* Sun Sep 25 2016 Greg Wildman <greg@techno.co.za> - 0.31-6
- Include ROM01 as well.

* Fri Dec 18 2015 Greg Wildman <greg@techno.co.za> - 3.2-1
- Initial spec.


